==> lms-1.6.1+libs.tar.gz: lms/modules/rtqueueadd.php <==
<?php

/*
 * LMS version 1.6.1 Ishta
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: rtqueueadd.php,v 1.15.2.2 2005/05/20 11:44:42 kondi Exp $
 */

$queue = $_POST['queue'];

if(isset($queue))
{
	if($queue['name']=='' && $queue['email']=='' && $queue['description']=='')
	{
		$SESSION->redirect('?m=rtqueuelist');
	}

	if($queue['name'] == '')
		$error['name'] = trans('Queue name must be defined!');

	if($queue['name'] != '' && $LMS->GetQueueIdByName($queue['name']))
		$error['name'] = trans('Queue with specified name already exists!');

	if($queue['email']!='' && !check_email($queue['email']))
		$error['email'] = trans('Incorrect email!');

	if(isset($queue['admins']))
		foreach($queue['admins'] as $key => $value)
			$queue['rights'][] = array('id' => $key, 'rights' => $value, 'name' => $queue['adminnames'][$key]);

	if(!$error)
	{
		$id = $LMS->QueueAdd($queue);
		$SESSION->redirect('?m=rtqueueinfo&id='.$id);
	}
}

$admins = $LMS->GetAdminNames();

foreach($admins as $admin) 
{
	$admin['rights'] = $queue['admins'][$admin['id']];
	$queue['nrights'][] = $admin;
}
$queue['rights'] = $queue['nrights'];

$layout['pagetitle'] = trans('New Queue');

$SESSION->save('backto', $_SERVER['QUERY_STRING']);

$SMARTY->assign('queue', $queue);
$SMARTY->assign('error', $error);
$SMARTY->display('rtqueueadd.html');

?>

==> lms-1.7.4+libs.tar.gz: lms/modules/rtqueueadd.php <==
<?php

/*
 * LMS version 1.7.4 Wraith
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: rtqueueadd.php,v 1.18 2005/05/27 15:35:21 alec Exp $
 */

$queue = $_POST['queue'];

if(isset($queue))
{
	if($queue['name']=='' && $queue['email']=='' && $queue['description']=='')
	{
		$SESSION->redirect('?m=rtqueuelist');
	}

	if($queue['name'] == '')
		$error['name'] = trans('Queue name must be defined!');

	if($queue['name'] != '' && $LMS->GetQueueIdByName($queue['name']))
		$error['name'] = trans('Queue with specified name already exists!');

	if($queue['email']!='' && !check_email($queue['email']))
		$error['email'] = trans('Incorrect email!');

	if(isset($queue['users']))
		foreach($queue['users'] as $key => $value)
			$queue['rights'][] = array('id' => $key, 'rights' => $value, 'name' => $queue['usernames'][$key]);

	if(!$error)
	{
		$id = $LMS->QueueAdd($queue);
		$SESSION->redirect('?m=rtqueueinfo&id='.$id);
	}
}

$users = $LMS->GetUserNames();

foreach($users as $user) 
{
	$user['rights'] = $queue['users'][$user['id']];
	$queue['nrights'][] = $user;
}
$queue['rights'] = $queue['nrights'];

$layout['pagetitle'] = trans('New Queue');

$SESSION->save('backto', $_SERVER['QUERY_STRING']);

$SMARTY->assign('queue', $queue);
$SMARTY->assign('error', $error);
$SMARTY->display('rtqueueadd.html');

?>
